@@ -21,6 +21,7 @@ public class EdgeWeight {
 	static DecimalFormat formatSmall = new DecimalFormat("#.###E0");
 	
 	public EdgeWeight(String weightStr) {
+		if (weightStr==null) throw new RuntimeException("weigthStr is not allowed to be null!");
 		this.weightStr = weightStr;
 	}
 	
@@ -29,6 +30,11 @@ public class EdgeWeight {
 		setWeightStr(weight);	
 	}
 	
+	public String getPreciseWeightStr() {
+		if (weight != null) return ""+weight[0];
+		return toString();
+	}
+	
 	private void setWeightStr(double weight) {
 		DecimalFormat format = Configuration.getInstance().getGeneralConfig().getDecFormat();
 		if (!Configuration.getInstance().getGeneralConfig().showFractions()) {
