@@ -16,6 +16,8 @@ public class MiscPanel extends OptionsPanel {
 
 
     private JCheckBox checkOnlineForUpdate;
+    private JCheckBox exportTransparent;
+    private JCheckBox unanchorEdges;
     
     private Configuration conf;
 
@@ -31,6 +33,11 @@ public class MiscPanel extends OptionsPanel {
     private void makeComponents() {
         checkOnlineForUpdate = new JCheckBox("Check online for updates");
         checkOnlineForUpdate.setSelected(conf.getGeneralConfig().checkOnline());
+        exportTransparent = new JCheckBox("Export images with transparent background");
+        exportTransparent.setSelected(conf.getGeneralConfig().exportTransparent());
+        exportTransparent.setEnabled(false);
+        unanchorEdges = new JCheckBox("If a node is dragged also all edges to this node follow");
+        unanchorEdges.setSelected(conf.getGeneralConfig().getUnAnchor());
     }
 
     private void doTheLayout() {
@@ -49,11 +56,21 @@ public class MiscPanel extends OptionsPanel {
         
         row += 2;
 
+        p1.add(exportTransparent, cc.xyw(1, row, 3));
+        
+        row += 2;
+        
+        p1.add(unanchorEdges, cc.xyw(1, row, 3));
+        
+        row += 2;
+
         add(p1);
     }
 
 
     public void setProperties() throws ValidationException {
        	conf.getGeneralConfig().setCheckOnline(checkOnlineForUpdate.isSelected());
+       	conf.getGeneralConfig().setExportTransparent(exportTransparent.isSelected());
+       	conf.getGeneralConfig().setUnAnchor(unanchorEdges.isSelected());
     }
 }
